Code Documentation
==================

lineage
-------

.. automodule:: lineage
    :members:
    :undoc-members:
    :show-inheritance:


lineage.individual
------------------

.. automodule:: lineage.individual
    :members:
    :undoc-members:
    :show-inheritance:

lineage.resources
-----------------

.. automodule:: lineage.resources
    :members:
    :undoc-members:
    :show-inheritance:

lineage.visualization
---------------------

.. automodule:: lineage.visualization
    :members:
    :undoc-members:
    :show-inheritance:
